##  Overview
Architecture transparency entails a comprehensive understanding of your IT landscape, business processes, and data flows, along with their dependencies and risks. This involves evaluating existing capabilities, applications, and interfaces to identify strengths, weaknesses, and areas for improvement. The as-is assessment provides valuable insights for data-driven decision-making and establishes a data foundation that guides the direction your organization wants to take with the ERP transformation.
**Note**
The approach described here is rather suitable for a new ERP implementation (Greenfield). If you plan a system conversion (Brownfield), your focus will be mostly on applications and interfaces. For a hybrid approach, you “play” between bottom-up and top-down scoping strategies.
In the Discovery phase, do the following:
  1. [Model SAP LeanIX Fact Sheets and build your repository](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bc6ab7a441014aa76cc690e760477__step_1._model_sap_leanix_fact_sheets_and_build_your_repository).
  2. [Scope ERP transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bc6ab7a441014aa76cc690e760477__step_2._scope_erp_transformation): Define the scope of your ERP transformation in close alignment with the business.
  3. [Report and communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bc6ab7a441014aa76cc690e760477__step_3._report_and_communicate): Establish a clear format for sharing results with diverse stakeholders and share various perspectives for a transparent view of the 'as-is' architecture.


The following overview provides a “Definition of Done” with Milestones that you should achieve in this phase, and EA-relevant Reports and KPIs suggested by SAP LeanIX that are explained in detail in a separate section Report and Communicate in each phase of the ERP Transformation.
Milestones |  KPIs/Reports
---|---
Identify your organization’s Objectives and the strategic relevance and maturity of the Business Capabilities supporting those Objectives. Understand which Business Capabilities are in scope of the ERP transformation. |  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ee9fc7a4410149e2aeed7a91e31a1_LowRes.png)
Understand which Application, Organization, and Interface Fact Sheets are affected by the Business Capabilities in scope. |  ![Image 3](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275715887a441014a07f8aece1ca5e60_LowRes.png)
Defined mandatory attributes (based on best practices from SAP LeanIX: e.g., lifecycle, Technical and Functional Fit, Business Criticality). |  ![Image 4](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c9b077a4410149f01a3bc8f2d9495_LowRes.png)


